@@ -6,7 +6,7 @@ use crate::fileapi;
 use crate::languageserver::BUFFERS_CACHE;
 use crate::scansubs::TREE_MAP;
 use crate::utils::treehelper::{get_pos_type, PositionType};
-use crate::utils::CACHE_CMAKE_PACKAGES_WITHKEYS;
+use crate::utils::{remove_bracked, replace_placeholders, CACHE_CMAKE_PACKAGES_WITHKEYS};
 use buildin::{BUILDIN_COMMAND, BUILDIN_MODULE, BUILDIN_VARIABLE};
 use std::collections::HashMap;
 use std::path::{Path, PathBuf};
@@ -288,7 +288,10 @@ fn getsubcomplete(
                         let h = ids.start_position().row;
                         let x = ids.start_position().column;
                         let y = ids.end_position().column;
-                        let name = &source[h][x..y];
+                        let Some(name) = replace_placeholders(remove_bracked(&source[h][x..y]))
+                        else {
+                            continue;
+                        };
                         let (is_buildin, subpath) = {
                             if name.split('.').count() != 1 {
                                 (false, local_path.parent().unwrap().join(name))
