@@ -12,6 +12,7 @@ use crate::{
     languageserver::BUFFERS_CACHE,
     scansubs::TREE_MAP,
     utils::{
+        replace_placeholders,
         treehelper::{get_position_string, point_to_position},
         CACHE_CMAKE_PACKAGES_WITHKEYS,
     },
@@ -35,6 +36,27 @@ pub static JUMP_CACHE: LazyLock<Arc<Mutex<JumpKV>>> =
 
 const JUMP_FILITER_KIND: &[&str] = &["identifier", "unquoted_argument"];
 
+// FIXME: I do not know the way to gen module_pattern on windows
+#[allow(unused_variables)]
+fn gen_module_pattern(subpath: &str) -> Option<String> {
+    #[cfg(unix)]
+    #[cfg(not(target_os = "android"))]
+    {
+        Some(format!("/usr/share/cmake*/Modules/{subpath}.cmake"))
+    }
+    #[cfg(target_os = "android")]
+    {
+        let Ok(prefix) = std::env::var("PREFIX") else {
+            return None;
+        };
+        Some(format!("{prefix}/cmake*/Modules/{subpath}.cmake"))
+    }
+    #[cfg(not(unix))]
+    {
+        None
+    }
+}
+
 pub async fn update_cache<P: AsRef<Path>>(path: P, context: &str) -> Option<()> {
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
@@ -155,9 +177,13 @@ pub async fn godef(
                 PositionType::NotFind => None,
                 #[cfg(unix)]
                 PositionType::FindPkgConfig => None,
-                PositionType::Include => include::cmpinclude(originuri, &tofind, client).await,
+                PositionType::Include => {
+                    let fixed_url = replace_placeholders(&tofind)?;
+                    include::cmpinclude(originuri, &fixed_url, client).await
+                }
                 PositionType::SubDir => {
-                    subdirectory::cmpsubdirectory(originuri, &tofind, client).await
+                    let fixed_url = replace_placeholders(&tofind)?;
+                    subdirectory::cmpsubdirectory(originuri, &fixed_url, client).await
                 }
             }
         }
@@ -331,21 +357,18 @@ fn getsubdef(
                             } else {
                                 // NOTE: Module file now is not works on windows
                                 // Maybe also not works on android, please make pr for me
-                                #[cfg(not(unix))]
-                                continue;
-                                #[cfg(unix)]
-                                {
-                                    let Some(path) = glob::glob(
-                                        format!("/usr/share/cmake*/Modules/{name}.cmake").as_str(),
-                                    )
+                                let Some(glob_pattern) = gen_module_pattern(name) else {
+                                    continue;
+                                };
+                                let Some(path) = glob::glob(&glob_pattern)
                                     .into_iter()
                                     .flatten()
                                     .flatten()
-                                    .next() else {
-                                        continue;
-                                    };
-                                    (true, path)
-                                }
+                                    .next()
+                                else {
+                                    continue;
+                                };
+                                (true, path)
                             }
                         };
                         if include_files.contains(&subpath) {
@@ -505,3 +528,28 @@ fn get_cmake_package_defs(
 
     Some(complete_infos)
 }
+
+#[test]
+fn test_module_pattern() {
+    #[cfg(unix)]
+    #[cfg(not(target_os = "android"))]
+    assert_eq!(
+        gen_module_pattern("GNUInstallDirs"),
+        Some("/usr/share/cmake*/Modules/GNUInstallDirs.cmake".to_string())
+    );
+    #[cfg(target_os = "android")]
+    {
+        std::env::set_var("PREFIX", "/data/data/com.termux/files/usr");
+        assert_eq!(
+            gen_module_pattern("GNUInstallDirs"),
+            Some(
+                "/data/data/com.termux/files/usr/share/cmake*/Modules/GNUInstallDirs.cmake"
+                    .to_string()
+            )
+        );
+    }
+    #[cfg(not(unix))]
+    {
+        assert_eq!(gen_module_pattern("GNUInstallDirs"), None);
+    }
+}
